@@ -1,8 +1,10 @@
 #!/bin/python2
 # -*- coding: utf-8 -*-
 
-from .core import *
+from .econtools import *
+from .generic import *
 from .plots import *
 from .njitted import *
 from .optimize import *
-from .la import *
+from .linalg import *
+from .datatools import *
